"""

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""

thoughts = [
    {
        "quote": 'I would probably be Scrooge-like, but am too lazy to put in the effort. Which also applies to non-Scrooge-like holiday behaviors. Perhaps "holiday-agnostic" sums it up. Much like honey badger, I just don\'t care.',
        "date": "12/19/2017",
    },
    {
        "quote": "Do we have a service that supports a call tree? For questions about ... press 1 (dump to google voice), for emergencies press 2 (bounce to a human)..., to send pizza press 3 (redirect to local pizza delivery service)...\n",
        "date": "12/19/2017",
    },
    {
        "quote": 'I would probably be Scrooge-like, but am too lazy to put in the effort. Which also applies to non-Scrooge-like holiday behaviors. Perhaps "holiday-agnostic" sums it up. Much like honey badger, I just don\'t care.\n',
        "date": "12/19/2017",
    },
    {
        "quote": "A cyclops baby would never know the joy of dressing as a pirate on halloween.\n",
        "date": "12/21/2017",
    },
    {
        "quote": "Implies that only HPC users are gullible enough to pay full price, which, given our half-witted decades long clinging to MPI, is a reasonable assumption.\n",
        "date": "12/31/2017",
    },
    {
        "quote": "I need to go to SRCF to beat a server into submission fix a problem. Taking the bus out there and then walking home after, so have a good weekend everyone.\n",
        "date": "1/12/2018",
    },
    {
        "quote": 'I wonder if there is a slack for viruses where this morning a virus messaged "Have forced Ruth to stay home today!" and all the other viri added   and  or said "Good work!".\n',
        "date": "1/19/2018",
    },
    {
        "quote": "If you had a 13 year old, you'd be happy to have some metal to stab it with.\n",
        "date": "1/23/2018",
    },
    {
        "quote": "I'm going down to nVidia today to get the nickel tour and have someone explain how the new EULA is actually a Good Idea(tm), should be back around 2:30-ish. If my    threshold is exceeded and I am arrested for excessive public old man ranting, do NOT help me make bail. This kind of behavior should not be encouraged, let the punishment fit the crime.\n",
        "date": "2/1/2018",
    },
    {
        "quote": "If I were a rapper, my name would be dubious M.A.C. and all my rhymes would end on octet boundaries.\n",
        "date": "2/2/2018",
    },
    {
        "quote": "This new world of constant surveillance is really challenging. Luckily I wore my dress hoodie today, so at least I look professional.\n",
        "date": "2/2/2018",
    },
    {
        "quote": "Not until I retire, I depend on users to justify my existance and I'm not ready to start the 'coasting to the finish' phase of life yet.\n",
        "date": "2/9/2018",
    },
    {
        "quote": 'First entry when I get my notebook: "Dear Notebook, Before I got you @kilian made fun of your pocket. But don\'t be sad, I like your pocket. You are my best friend, notebook."\n',
        "date": "2/13/2018",
    },
    {
        "quote": '"Dear Notebook, They continue to make fun of you, even @v who we thought was really nice is doing it. But don\'t be sad, we still have each other. BFFs, griznog"\n',
        "date": "2/13/2018",
    },
    {
        "quote": '"Dear notebook, Making fun of you became so complex that they created a container API and standard for mean notebook puns. The group is meeting with  VC this week and as much as it pains me, I am abandoning you in the hopes that my association with the pun container standard will result in a profitable IPO or buyout of our startup. It\'s been fun, @griznog"\n',
        "date": "2/13/2018",
    },
    {
        "quote": "I have a dentist appointment in the morning, 4 leaky fillings spread across 3 quadrants, so I'll be in 11-ish and probably grumpy. Or, grumpy about things other than cloud and systemd since grumpy is a steady state.\n",
        "date": "2/21/2018",
    },
    {
        "quote": "I had really good intentions of coming in once the sun was out, but my wife started making a pizza. Y'all are really nice people and I miss you, but... pizza. So maybe physical presence later this afternoon, until then virtual presence continues.\n",
        "date": "2/26/2018",
    },
    {
        "quote": "A good  Software Carpentry project would be to build a coffin for Microsoft products.\n",
        "date": "3/2/2018",
    },
    {"quote": "I am Batman!\n", "date": "3/5/2018"},
    {
        "quote": "Just an FYI, it would appear I'm running about an hour late this morning. I suspect a government plot of some sort is behind this.\n",
        "date": "3/12/2018",
    },
    {
        "quote": "This years time change was the best time change ever. People are saying, I hear things, that no president has ever had a time change with this many minutes. This time change was yuge. Biggest ever. America is one hour greater than the rest of the world. Believe me, when we put tariffs on time, and people say you can't put a tarrif on time, but our tariffs on time will be the best ever. The best.\n",
        "date": "3/12/2018",
    },
    {
        "quote": "There's no such thing as 1.29 inches of pizza, that has long since crossed into casserole territory.\n",
        "date": "3/13/2018",
    },
    {
        "quote": "We are prohibited from using good technical solutions by arbitrary red tape.\n",
        "date": "3/15/2018",
    },
    {
        "quote": "I will submit a ticket and we'll see which turtle wins this race.\n",
        "date": "3/15/2018",
    },
    {
        "quote": "I used to cope with the world by remembering that for all people, from birth to death, they experience the universe as if they are the center of it. That has great explanatory power when dealing with humans. Now I have to extend that to include that all developers experience the world as if their Ubuntu laptop is the center of the computing universe.\n",
        "date": "3/22/2018",
    },
    {
        "quote": "Yes, everyone wants their favorite hobby to be a real science, but at least for me I respond to what the people using the system ask for and none are asking for this yet. I generally assume they are the experts in their fields and when they need it, they'll let me know and be in a hurry for it. The sysadmin and cluster do not drive the science, the science drives the sysadmin and cluster.\n",
        "date": "3/27/2018",
    },
    {
        "quote": "(I plan to celebrate by eating something which has been proven to shorten my life span.)\n",
        "date": "3/23/2018",
    },
    {
        "quote": "I don't think it's a waste, there seem to be some cases where containers for deployment and scaling make a lot of sense. If I were suddenly thrust into a business environment scaling up a web service I suspect I'd do it all with containers. That I don't see how it is useful in a research environment may simply be a lack of vision on my part, and I'm open to evidence to clear that vision up. But so far the arguments for containers (and cloud) in research have been extremely weak. Containers are a very effective hammer, but not every problem is a nail.\n",
        "date": "3/23/2018",
    },
    {
        "quote": "The self-loathing is a bonus, no extra charge for that.\n",
        "date": "3/23/2018",
    },
    {
        "quote": 'I once showed a user of a very popular chemistry code how different compiler flags produced very inconsistent results and suggested that maybe there was an issue with the code itself. The reply was, paraphrasing, "I don\'t care, this is the code people in this field publish with so just pick one."\n',
        "date": "3/23/2018",
    },
    {
        "quote": "More troubling to me is that many of the portability issues you describe stem not from actual techincal difficulties but from sysadmin choices and system policies. Containers as a workaround for crappy system administration scares me more than every other use case.\n",
        "date": "3/23/2018",
    },
    {
        "quote": "If you can't be with the one you love, love the one you're with, or just grind your teeth and trudge forward.\n",
        "date": "3/28/2018",
    },
    {
        "quote": "It's possible to love someone and spend a lot of effort helping them while sometimes wishing they didn't exist and squashing the urge to end them. My kids taught me how to do that.\n",
        "date": "4/19/2018",
    },
    {
        "quote": "Parenting is really good practice for being a cluster sysadmin. Both jobs require providing a safe environment for people to try things and fail.\n",
        "date": "4/19/2018",
    },
    {"quote": "All kids think they deserve sudo\n", "date": "4/19/2018"},
    {
        "quote": "job security. I get scared when any of this works too well.\n",
        "date": "4/12/2018",
    },
    {"quote": "We are some seriously destructive meatsacks.\n", "date": "4/26/2018"},
    {
        "quote": "The real turning point for humanity will be when more incoming solar radiation is used by computing than by photosysynthesis. Human induced climate change is just a training exercise, once we find the magic solar panel material that hits 70% or 80% efficiency, we'll cover the entire planet so we can drive better targeted ads.\n",
        "date": "4/26/2018",
    },
    {
        "quote": "I do like to optimize. With enough power/control I think I could destroy the human race at least 10x faster than we are doing it now.\n",
        "date": "4/27/2018",
    },
    {
        "quote": "It's worth remembering that it's only been 60 years, give or take, since Salk said this about his discovery of the polio vaccine: 'When asked who owned the patent to it, Salk said, \"Well, the people I would say. There is no patent. Could you patent the sun?\"'My how far we've come as humanitarians. Viva la markets! Huzzah for the lawyers!\n",
        "date": "4/30/2018",
    },
    {
        "quote": "Credit card numbers aren't private, they are secure. Money in my wallet is a well known concept, that people have money is a given in most cases (even if not very much) so it's not a matter of privacy to protect your money (or other possessions), just security. Privacy is not allowing people to know how much money, or how you fold it in your wallet, or how you spend it. We have security (not giving out credit card number) but we no longer have privacy, as soon as I buy something on Amazon mysteriously lots of other places start marketing more of that thing to me. Privacy is dead, but security still has a few breaths left in it.\n",
        "date": "5/15/2018",
    },
    {
        "quote": "The bus driver left me alone in the bus, keys in and running. If I steal it can I later claim this was a pen test and I am the red team?\n",
        "date": "5/2/2018",
    },
    {
        "quote": "Because having my car's window smashed AND my package stolen is a huge improvement in service.\n",
        "date": "5/3/2018",
    },
    {
        "quote": "We'll know that Amazon has truly acheived world domination when amazon lockers become a standard architectural feature on new construction and are sold at Home Depot.\n",
        "date": "5/3/2018",
    },
    {
        "quote": "griznog’s law #12: Every person added to an existing cc list will, by some as yet unexplained compulsion, suggest trying the things that have been previously tried. They will NOT, however, do or endorse any of the things the sysadmin has been begging someone, anyone, to do since the first message in the thread.\n",
        "date": "5/10/2018",
    },
    {
        "quote": "Walked across Cambridge and Boston (downtown) this morning, had forgotten how much I like the city. Some observations:1. After living in (more or less) smoke-free zones for the last 5 years, I had forgotten that smoking is still a thing people do.2. If you are smoking, may as well get your food/beverage at Dunkin Donuts, can't taste it anyway. High DD density area.3. Real cities lay out the downtown area as an inpenetrable hedge maze. What a great place to be a pedestrian.4. I had forgotten that there exist pedistrians who can and will stare down a dump truck with 1 second left on the walk signal, and win.5. The Longfellow bridge is being renovated, all the old wrought iron railings have been stripped and refinished, sidewalks are widened to be more open for people and bikes. It'll be really nice when it's done. This is one of my favorite bridges (the iron and stonework are great).6. I don't like crowds, but when they are unavoidable I like people  crowded sidewalks more than car crowded streets.\n",
        "date": "5/16/2018",
    },
    {
        "quote": "I had high hopes for anaconda. I still think there are some useful things to learn from the attempt. But, there was also a time a few years ago when I thought Docker and containers were the way to go so I am clearly a slow learner. systemd has been a horrible idea from day one, not even any good intentions to fall back on for redemption.\n",
        "date": "5/16/2018",
    },
    {
        "quote": "rpath is like Halloween candy with a razor blade inside.\n",
        "date": "5/16/2018",
    },
    {
        "quote": "I hate the word \"actionable\". It really irritates me. It' a loathing so deep I can't even get enough brain function around the rage to use it in a stupid way as an illustration. Or, put another way, my hatred for the word is actionable.\n",
        "date": "5/17/2018",
    },
    {
        "quote": 'me: shoots self in face\n user: "Oh, I\'ll just install the package locally then."\n me: "It\'s conflicting with your $HOME R install, take that out of your PATH"\n user: "I get an error when I load it, \'can\'t shumboozel /home/user/R/...\'\n me: "Sure" (installs package...)\n user: "Can you install this R package, it has a lot of dependencies."\n',
        "date": "5/23/2018",
    },
    {
        "quote": "It would be a huge timesaver to have your pirated movie come with a player and all malware pre-installed. Maybe containers are useful after all.\n",
        "date": "6/4/2018",
    },
    {
        "quote": "Some of the most profoundly heartbreaking moments I've had in my life are when I've ordered something and then discovered it's shipping via DHL. My lip quivers, I sniffle a bit, then trudge onward with slumped shoulders.\n",
        "date": "6/4/2018",
    },
    {
        "quote": "You can either tell where it's at or how fast it is. Stop trying to figure out where it's at and maybe it'll go faster.\n",
        "date": "6/7/2018",
    },
    {
        "quote": "Saying \"griznog is 5 times faster than a 2 year old half-wit toddler in the 100 yard dash\" doesn't really mean I'm headed to the olympics next year. But these articles rarely give any details on the capabilities of their equivalent of the two year old half-wit toddler.\n",
        "date": "6/7/2018",
    },
    {
        "quote": "There should be a restaurant that serves all food in dino-dishes. I want my watercress salad in a Brontosaurus bowl.\n",
        "date": "6/11/2018",
    },
    {
        "quote": "Damn, I felt special because she sent directly to me and Keith. So what you're saying is I'm just another customer and really have no special relationship with Dell? Like I'm just a regular person? Pants one leg at a time and all that?\n",
        "date": "6/11/2018",
    },
    {
        "quote": "This leech was in my lettuce. I almost ate him. What we don't know is how many of his friends I did eat.\n",
        "date": "6/12/2018",
    },
    {
        "quote": 'You know what makes the US really boring? The lack of border disputes. It\'d be awesome if, for instance, Alabama invaded/annexed the Florida panhandle and started an "incident". For a Russian flavored definiton of "Make America Great Again" I really think a few of these border shufflings have to be kicked off, ASAP.\n',
        "date": "6/13/2018",
    },
    {
        "quote": 'In the continuing Google saga of "Hey, that works well, how can we stack a bunch of shit on and make it suck" the latest google-chrome-stable release is not living up to it\'s name and seems to have decided to get way to close to both the video and network stacks of CentOS and Fedora.\n',
        "date": "6/15/2018",
    },
    {
        "quote": "Yes, having all my old crap be the same brand of old crap is very appealing to me.\n",
        "date": "6/8/2018",
    },
    {
        "quote": "With Microsoft having recently invented BASH in Windows 10, it's no surprise that Google has responded by inventing NFS in the cloud. I'm tempted to drive by both companies headquarters and invent fire.\n",
        "date": "6/27/2018",
    },
    {
        "quote": "This is why I don't read too closely. If you just skim articles like this you can pretend the AI is self aware and attended a small liberal arts school in the Northeast before discovering it's gift for organizing the elements into the periodic table. Also that the AI likes Star Trek fan fiction.\n",
        "date": "6/25/2018",
    },
    {
        "quote": "Specifically, to Google the open butt means:\n Also, once again (and I never get tired of this) the cloud-to-butt chrome plugin pays big dividends.\n The power to pick up an app and move it -- to and from on-premises, our butt, or another butt -- at any time.",
        "date": "6/27/2018",
    },
    {
        "quote": 'Wow, I somehow missed that "over 2,200" employees are moving to RedWood city. That is a lot of warm bodies. I had been assuming it was IT only, which shows how much attention I pay to the parts of life that don\'t answer to ssh.\n',
        "date": "6/27/2018",
    },
    {
        "quote": "I've always wanted to be like Dick G. and all those similar to him, but sadly I'm just too damn lazy to put that much effort into myself. I can, however, do impersonations.\n",
        "date": "7/3/2018",
    },
    {
        "quote": "I think Facebook and plenty of other easy to use user facing tools have taught us that making it easier for people to communicate does not guarantee improved quality of communication. Lack of a tool to facilitate the help request may not be the real problem.\n",
        "date": "7/7/2018",
    },
    {
        "quote": "In spite of the rise of AI, we still live in a world where there is no substitute for simply knowing what you are doing. Although checklists seem to allow a lot of really dumb people to do complex tasks.\n",
        "date": "7/7/2018",
    },
    {
        "quote": "You just described every IT department everywhere. IT seems to always become the tail that wants to wag the dog.\n",
        "date": "7/12/2018",
    },
    {
        "quote": "For background on this rant, the JSON config file to run the application via Rabix is 41,035 lines long. That' s 41k lines of config to run an application. Previously I thought this only happened with proprietary crap that needed to generate an arbitrary monetized support environment as part of the business model, but now you can get it for free with open source.\n",
        "date": "7/9/2018",
    },
    {
        "quote": "I've long since lost count of the number of these types of tools. Of the now dozens+ I've dealt with over the years, I can't recall a single one that did better than an adept Makefile author with a shared filesystem available could have done. But there seems to be no shortage of people/groups who, while apparently unable to muster the intellect to process the make manpage, seem to suffer from the delusion that they are deep enough thinkers to \"disrupt\" the concept of a workflow and somehow make \"reproducible\" things even though we've had reproducible things since the very first computer program ran successfully (before that its bugs were reproducible). This (and things similar) leave me in a conflicted state. As an ecologist, I cling to the idea that diversity is a Good Thing(tm) and because of this I cringe a bit at, for instance, the elimination of mosquitoes, as I see everything as part of the whole and the whole as evolving and changing continuously. Thus I value mosquitoes, even though I find them annoying. But applying that analogy to the tech world leaves me wondering, are all new ideas in this diverse realm just mosquitoes? What is the value of an ecosystem made up solely of subtly different parasites? Circling back around to the idea of bullshit jobs, I wind up wondering how much of our computing technology is bullshit tech? I spent some time in my logs this morning and watched systemd and dbus doing their thing. Absolutely nothing of value provided by either. Before they existed we could watch movies, play sounds, edit files, reboot our machines, etc... Now things like systemd more and more become the source of problems, with a negative feedback loop as more projects incorporate this bullshit into their own bullshit. Would Poettering be in a position to pepper us continually with brokenness and stupidity if our culture didn't equate morality and goodness with $HOURS_WORKED? He (and I, sadly) had to find something to do to be viewed as valuable to society; wouldn't we all be better off if he (and all the other mosquito breeders) had been raised in a world where teaching and service were the highest valued ways to spend time. A world where crap work like programming was left to degenerate, anti-social monsters who couldn't function out in normal society? Of course, maybe I am underestimating the degenerate, anti-social monster population and things like workflow tools and systemd were inevitable irrespective of societal values.\n $TOOLNAME is a suite of open-source development tools for creating and running computational workflows. $TOOLNAME Tools are developed by $GROUP_OF_PEOPLE with the goal of empowering researchers and developers to easily run reproducible analyses at scale.\n What is $TOOLNAME?\n I'm troubleshooting this thing, Rabix, and when I went to the website the first paragraph struck me as a beacon for humanity's failing approach to computation. As I continue to wander down the rabbithole of the \"bullshit jobs\" meme, considering what human activity and mores are actually worthwhile and contribute to a meaningful existence, things like this are standing out more and more often to me. I'll quote that paragraph here with variables as placeholders and ask the rhetorical question, how often does this get repeated across the breadth of our technology landscape?\n",
        "date": "7/9/2018",
    },
    {
        "quote": "I get that, but am left wondering if the world needs Yet Another Workflow Management Tool or if it needs more people to build homes for the homeless. As a society we don't reward people who build homes for the homeless, but put together a buzzword compliant home page for YAWMT and you might get VCs to write a check or hit the holy grail of being bought by Google. I think, although possibly not expressed well, that tech is mirroring the pseudo-work economy of bureaucrats and red tape, only we do it with pip and containers and pretend like that effort matters in the same way an insurance company claims processor convinces themselves that denying some child's prescription payment is important and useful work because the particular disease doesn't match a policy and the policy must be enforced. We are victims of our own delusions of utility.\n",
        "date": "7/9/2018",
    },
    {
        "quote": "Those may be tears ot joy or sadness. Too early to tell, but I had to pick an emoji.\n",
        "date": "7/9/2018",
    },
    {
        "quote": "On the other hand I also lived in Utah for 16 years around people who update their historical documents annually, interpreting them \"as written now\" and quietly discarding the historical versions which remind them that they used to be assholes. So the other end of the spectrum isn't any better. It's important to live in the modern world, but never lose sight of the fact that back when you were ignorant and intolerant, you were an asshole.\n",
        "date": "7/10/2018",
    },
    {
        "quote": "The true path to happiness is lowering expectations.\n",
        "date": "7/10/2018",
    },
    {
        "quote": "RE: The cio channel, I just bought that Bullshit Jobs book and plan to read it on my trip, but having listened to several of his talks and interviews, it feels like he has brought structure to something that has been bugging me for decades. The #cio channel is a great example. Given that one class of bullshit job is the flunkie, who exists only to inflate the importance of a superior on the org chart, what you see there is a stream of flunkie confessions/interviews. Without knowing anyone posting there, I'd make the blanket assertion that although they may be great and very nice people, <Employer> IT and <Employer> could probably function perfectly well if they never showed up for work again.\n",
        "date": "7/12/2018",
    },
    {
        "quote": "There is an ever present danger in thinking what we do is actually a) hard or b) important enough to stand on it's own merit. Running an academic cluster environment is best when it's so messy that support has to be one on-one and is too complex to be automated and we as cluster herders have no line, not even a blurry one, between us and the researchers. At the end of the day if we find ourselves setting up a cluster via some arbitrary \"best practices\" and then pointing users at some tool they can paste jobs scripts into without ourselves having some basic knowledge and interest in the science being done, then we may as well don long pants and a collar and start posting to #cio with our own PowerPoint presentations about group synergies and adhering to the mission.\n",
        "date": "7/12/2018",
    },
    {
        "quote": "What I lack in courage I overcompensate for with stupidity.\n",
        "date": "7/12/2018",
    },
    {"quote": "Don't confuse stupidity with courage.\n", "date": "7/12/2018"},
    {
        "quote": "I'm tempted to create a site for \"Give griznog root.\" A simple curl | bash that will open firewalls, add ssh keys and modify sshd_config to give me full access to the system. Seems perfectly reasonable to me that everyone should give me root on all systems, no harm in offering this, I'll call it Griznog as a Service (GaaS).\n",
        "date": "7/12/2018",
    },
    {
        "quote": 'It\'s a "free" service. Hint: our business model depends on mining bitcoins.\n',
        "date": "7/12/2018",
    },
    {
        "quote": "Actually probably the largest coding project I ever did was in Perl. 6 months after not touching it I tried to make some changes to it, it was like opening up hieroglyphics. Even with my copious comments I was lost. That's when i stopped using Perl and switched to python.\n",
        "date": "7/13/2018",
    },
    {
        "quote": "Buying stuff, like food and gas, is fun when you aren't in California. Just some FYI.\n",
        "date": "7/19/2018",
    },
    {
        "quote": "You talk to people, but more exciting it's possible to buy a hamburger and eat it without thinking you should probably get a second job on the side to cover that nasty food habit.\n",
        "date": "7/19/2018",
    },
    {
        "quote": "The danger of making finance the most highly valued skill in a culture is that you can't cure cancer with derivatives and pork belly futures don't taste near as good as actual bacon.\n",
        "date": "7/19/2018",
    },
    {
        "quote": '"Python has brought computer programming to a vast new audience" … an audience so annoying that he stepped down.\n',
        "date": "7/19/2018",
    },
    {
        "quote": "I’ve been pondering that for myself, and what I’ve got so far is that while my job is not 100% bs, it does have some amount of bs component to it which I can’t put a finger on. What we do has a significant teaching component to it for our interaction with users, which is clearly not BS. As a sysadmin there is another significant bit where increasing efficiency of usage is not BS. But (using SCG as an example) there is a portion of it where the system itself is propping up arbitrary accounting practices which are pretty clearly just bullshit. The question then is how to balance the BS/nonBS ratio to a satisfactory level?\n",
        "date": "7/23/2018",
    },
    {
        "quote": "Currently sitting in rain of biblical proportions in a parking lot. We found a high spot and are watching the water rise to levels where it is getting into some people's cars who parked closer to the lot drains. Beginning to wonder if Amazon delivers arks.\n",
        "date": "7/24/2018",
    },
    {
        "quote": "If you put your hype in a box, then you don't know if the hype is alive or dead until you open the box. Looks like someone opened the box on this one.\n",
        "date": "7/31/2018",
    },
    {
        "quote": "I thought my first victim was just suffering from a complex case of cluelessness, but now I have at least two, one of which having had success previously.\n",
        "date": "8/1/2018",
    },
    {
        "quote": "I smell like chocolate chip cookies at the gym, primarily because I'm there trying to burn off that dozen chocolate chip cookies I ate earlier.\n",
        "date": "8/1/2018",
    },
    {
        "quote": "This is a tough topic. I like to think of race as a marker for the underlying culture. Some cultures value education and hard work, others less so. While I too am opposed to seeing a culture that values it (as many Asian cultures do) be restricted due to having the marker, at the same time how do we encourage other cultures to value it if they can't get admitted? This is the classic bootstrapping problem, how to people pull themselves by the bootstraps if they can't get bootstraps? The real solution is to provide free tuition to qualified students at public universities and community colleges and wait 2 or 3 (or more in some cases) generations for the problem to resolve itself. What Ivy league schools do impact, however, is the 1%. From that perspective one could say that considering race to increase diversity is reducing the white privilege over the long term and preventing it from becoming a swap for white for some other cultural optimization at that upper income level. I'd prefer to tackle that problem with a very, very progressive income tax and a big change in how capital gains are taxed (to fund the aforementioned public educations), but I don't see that happening anytime soon.\n",
        "date": "8/2/2018",
    },
    {
        "quote": "I do wonder sometimes if humans will ever interbreed to the point we're all just some homogeneous shade of beige and we have to find some other stupid way to divide into categories to argue about.\n",
        "date": "8/2/2018",
    },
    {
        "quote": "Oh, nevermind. I forgot about god so that's not a problem.\n",
        "date": "8/2/2018",
    },
    {
        "quote": "Ok, I'm reversing my negative position on <Location>. Now that I am aware of its proximity to Ikea I'm totally sold on how <Location> will improve <Employer>'s ability to be a leader in education and research. The project really should have opened with the \"easy access to Ikea\" feature.\n",
        "date": "8/3/2018",
    },
    {
        "quote": "If you have to put science in the name, then it probably isn't a science.\n",
        "date": "8/5/2018",
    },
    {
        "quote": "Well, when you boil it down we are all walking metabolic reaction vessels. Instead of an Erlenmyer flask I am a griznogian soft bottle.\n",
        "date": "8/11/2018",
    },
    {
        "quote": "It's an old item on my SCG to-do list. Sadly our current software stack is a recipe with a lot of cooks involved.\n",
        "date": "8/21/2018",
    },
    {
        "quote": 'You keep pointing out that I am lazy and should just do this, but fair warning: I am immune to shame. If you were to say "lmod comes with free pizza..." then that might be more effective.\n',
        "date": "8/21/2018",
    },
    {
        "quote": "I spent a semester as a TA in a lab/class that had brains in jars. Which is to say, I have a lot of experience working with containerized brains, from back before containers were cool.\n",
        "date": "8/7/2018",
    },
    {
        "quote": 'I listened to an interview with a doctor who said he could send a bill with two clicks, but it took minutes of effort to enter a diagnosis. The interface becomes optimized for its intended purpose and actually healing people is a secondary (tertiary?) purpose of our health care system. Maintaining the cubicle based white collar welfare program is the primary mission. Although I can\'t find the quote now, even Obama admitted this saying (something to the effect of) "a single payer system would eliminate millions of data entry jobs and require doing something for those workers."\n',
        "date": "8/9/2018",
    },
    {
        "quote": "Fields should be ranked by how much compute capacity would be required to produce all possible publishable results. Then immediately after doing that a new journal for algorithms to produce those rankings should be established.\n",
        "date": "8/10/2018",
    },
    {
        "quote": "Speaking as a member of the group in question and having the mentioned equipment, there is not much funnier than white guys getting punched in the nuts. It's accurate to say the world could use more of that.\n",
        "date": "8/14/2018",
    },
    {
        "quote": "Everything is offensive, being offended is one of the most popular pastimes these days. I prefer to be outraged and highly offended, just being offended is so commonplace. To be just plain offended is the domicile of the half-witted, an act of a  simpleton who lacks true commitment. Simply being offended...ain't nobody got time for that.\n",
        "date": "8/14/2018",
    },
    {
        "quote": 'I remember early on in my career how exciting it was to go to a conference and listen to presentations and feel like I was part of this cutting edge field of HPC, to be around people from teh Beowulf list who were doing all this cool stuff with commodity hardware. A decade later I knew some of the people in the growing field and I started to get the feeling that a significant amount of it wasn\'t really cutting edge but instead, marketing. Another decade and I\'d been involved in some of it (always carefully avoiding having my name attached) and I realized it was mostly bullshit. Now fully jaded, I can\'t watch a presentation or read a paper without trying to reverse engineer all the ludicrousness that is probably behind it.  I despise the  process by which the excitement of learning something new by playing around with things gets turned into a rinse/repeat cycle of slightly modified posters and presentations to "build careers" and create "business models".  I hope that there is never the equivalent of this picture of me anywhere out there, especially associated with the typical poster/presentation/paper busywork.\n',
        "date": "8/15/2018",
    },
    {
        "quote": "This is extra funny for me due to my time in Utah permanently associating “elder” with mormon missionaries and his picture being pretty much a spitting image of a mormon missionary. Just needs a name tag, “HPC Elder Cuff”, out preaching the massively parallel gospel.\n",
        "date": "8/21/2018",
    },
    {
        "quote": 'I like that they call it "Aspera Connect" because being forced to use it makes me want to "connect" with a vendor of soft, supple but strong rope so it doesn\'t chafe my neck when I hang myself after depression sets in from using Aspera Connect.\n',
        "date": "8/22/2018",
    },
    {
        "quote": "I may have just started liking web interfaces to clusters more after realizing if someone only accesses via a web interface it's unlikely they'll ever break .bashrc. Of course what will I do with the 50% of my time I currently spend troubleshooting people's self-inflicted wounds? I think, origami.\n",
        "date": "8/24/2018",
    },
    {
        "quote": "Struggling to get a handle on bioinformatics tools and basic job script writing? What you need is a multi-kernel notebook fronting a workflow engine!\n",
        "date": "8/25/2018",
    },
    {
        "quote": "This was 12-ish years ago. Things were different then, I guess. No cloud. no containers. python was just a language. Perl still mattered.\n",
        "date": "8/29/2018",
    },
    {
        "quote": "I got into a great argument with one of the admins (pro tip: probably not a good idea to argue in an interview). He insisted provisioning 4096 nodes was really hard. I insisted you set up one provisioning server, measure it's capacity to provision nodes, then set up 4096/capacity provision servers and job done. We agreed to disagree.\n",
        "date": "8/29/2018",
    },
    {
        "quote": "Data organization requires standards, which leads to the old xkcd cartoon about standards. Or worse, XML.\n",
        "date": "8/29/2018",
    },
    {
        "quote": "I can recall sitting down with librarians to talk about this problem 20+ years ago. It's akin to solving global warming, except you don't even have the impending doom of the loss of civilization to potentially motivate people. Nobody wants this problem solved, they want their specific problem solved.\n",
        "date": "8/28/2018",
    },
    {
        "quote": "I think Microsoft is a fan of bloat in general. A few more features will make the product sell better, the utility of those features is never questioned. I get that every time I want to put in a location as well. You’d think they could at least detect my location and get it accurate down to the state level.\n",
        "date": "8/30/2018",
    },
    {
        "quote": "I succumbed to the pull of happy donuts this morning. Two dozen cronut holes, knock yourself out with a sugar coma.\n",
        "date": "8/31/2018",
    },
    {
        "quote": "\"As the sysadmin stood on the ladder reaching over the top of the rack to gently pushing the fiber beneath a bundle of cables and to the switch, he pondered the universe and his mind drifted to the endless series of MCE correctable error messages emanating from the system below. A screenplay began to form in his mind, working title 'The Silence of the DIMMs.' \"\n",
        "date": "8/31/2018",
    },
    {
        "quote": "We are fairly simple creatures, throw us the occasional beer, donut and pizza, send us hardware (in quantities that are powers of 2!) and lock us in the basement and we are happy.\n",
        "date": "8/31/2018",
    },
    {
        "quote": "I said they were surprisingly powerful, I didn't mean container fanbois couldn't screw them up.\n",
        "date": "9/13/2018",
    },
    {
        "quote": "No one should listen to my rants. I forced my kids to listen (well, to sit within earshot without hearing protection) and nothing good came from it, they still made all the stupid mistakes I tried to warn them about via rant and example. Better to spend time on facebook.\n",
        "date": "9/17/2018",
    },
    {
        "quote": 'A CIO has to make org changes, its part of the cio equivalent of peeing on territory, it\'s how they "add value". Without budgetary motivations these are usually benign relabeling and by the third or fourth cio they will start cycling back to a prior org chart. SRCC is too small and has too few managerial roles to matter in a first round, no need to worry unless he suddenly takes an interest in research. With 800 other drones in the hive to play with that is unlikely.\n',
        "date": "9/1/2018",
    },
    {
        "quote": "I have dedicated Internet! This is one high-class trailer park now.\n",
        "date": "9/4/2018",
    },
    {
        "quote": "I don’t think “label has been printed” qualifies as “your package has shipped.” Just sayin’.\n",
        "date": "9/5/2018",
    },
    {
        "quote": "If you hardcode your program to always download 2.3GB of data from S3 each time it's ran, even when debugging stuff, is it appropriate to then call your tool \"smart\" right in it's name? I think not.\n",
        "date": "9/6/2018",
    },
    {
        "quote": "You can't throw a rock without hitting an accountant or HR person.\n",
        "date": "9/7/2018",
    },
    {
        "quote": "Super adorable jumping all over your face at 5:30 am on Saturday. Yeah, adorable. There are worse ways to wake up than unconditional love, however, there's also sleeping in.\n",
        "date": "9/8/2018",
    },
    {
        "quote": "Sandboxing Cycle https://xkcd.com/2044/. Eventually we'll run out of metaphors and the cycle will have no choice but to end.\n",
        "date": "9/10/2018",
    },
    {
        "quote": 'old and somewhat reliable. That\'s what I want on my tombstone, "he was old and somewhat reliable, like a Macbook Pro before USB C and that stupid touchbar replaced the function keys"\n',
        "date": "9/12/2018",
    },
    {
        "quote": 'I have worked with numerous "data scientists." They basically fell into two categories: 1)  a small number who really new what they were doing and were good at it and 2) a large number who had self-appointed themselves "data scientist" and mastered some buzzwords but were pretty worthless. Several from category 2 bounced out to large salaries. The growing pains of a new "field" hurt, but are also an opportunity to make some fat stacks for people willing to bluff.\n',
        "date": "9/12/2018",
    },
    {
        "quote": "The first rule of compute club is that no one talks about compute club. Everybody brags about how big their storage is though.\n",
        "date": "9/12/2018",
    },
    {
        "quote": "I think we all need to tread carefully now that we know @v can scare a hurricane into going around her.\n",
        "date": "9/13/2018",
    },
    {
        "quote": "It turns out doing every possible pairwise comparison for multiple compare approaches and storing them all in python dictionaries in memory takes a lot of time and memory.\n",
        "date": "9/17/2018",
    },
    {
        "quote": "If you have the means, I highly recommend picking one up. (Not really, but I felt like quoting Ferris Bueller.)\n",
        "date": "9/17/2018",
    },
    {
        "quote": "In a world of big data, any major online service/company would be able to out a superhero in short order. There is no anonymity anymore, even for mutants or people with superpowers. Privacy is dead for us all.\n",
        "date": "9/19/2018",
    },
    {
        "quote": "Although a 75 Gb app stack is pretty pathetic too. If your app stack isn't measured in TB, you aren't doing biology.\n",
        "date": "9/25/2018",
    },
    {
        "quote": "Oh yeah, that's how the government works. It's your fault and everything we break punishing you is also your fault.\n",
        "date": "9/27/2018",
    },
    {
        "quote": "The modern world is a weird and wonderful place that continuously reminds me how utterly clueless I am with respect to interacting with the humans.\n",
        "date": "9/28/2018",
    },
    {
        "quote": '"National" implies it\'s my duty as an American to know what a cinnamon bun is. Is it some GMO hybrid of a pesticide resistant Cinnamon Roll with a factory farming tolerant strain of Sticky Bun? By not knowing what a Cinnamon Bun is do I run the risk of delaying progress toward making America great again? My patriotism is on the line here and my pastry inadequacies may be threatening the very foundations of our democracy.\n',
        "date": "10/1/2018",
    },
    {
        "quote": "A little more would have been nice. It basically made our dust in the yard sticky so the dogs track in more dust but wasn't enough to turn it to full on mud. Plus it would have been nice to get a full scale test of my recent landscaping/drainage/contouring efforts instead of just getting it all damp.\n",
        "date": "10/2/2018",
    },
    {
        "quote": 'Anyone who assumes I have Excel on any computer I use should have their "talk to griznog" privileges revoked.\n',
        "date": "10/2/2018",
    },
    {
        "quote": "While I'm not particularly fond of conferences, a presentation I wouldn't mind giving is \"How we eliminated systemd in our cluster and saved the world.\"\n",
        "date": "10/5/2018",
    },
    {
        "quote": "This makes me think there is still hope for humanity. Except for the pancakes and syrup making everyone diabetic. But, still...\n",
        "date": "10/10/2018",
    },
    {
        "quote": "The sad reality is that the universe doesn't work this way. In the same way we carry DNA and RNA that is billions of years old, we are stuck with legacy code. Organisms aren't rewarded by evolution for making giant rewrites, and programmers aren't rewarded by HR for making things simpler or starting over fresh.\n",
        "date": "10/11/2018",
    },
    {
        "quote": "Administrative and meeting overburden that arises from good intentions is still administrative and meeting overburden. For me personally I think there are better ways to spend both the pres/prov time and whatever staff resources are devoted to this kind of stuff; given the choice I would have opted out. <Employer> tells me how much they appreciate me twice a month, and I am happy each time it happens.\n",
        "date": "10/11/2018",
    },
    {
        "quote": "The problem with working from home is two-fold. 1) I become a hobbit, walking around barefoot and thinking about what I'll have for third breakfast. 2) all creatures here, from spouse to smallest puppy think I stayed home to entertain them.\n",
        "date": "10/11/2018",
    },
    {
        "quote": "Can we assume that the pups with two dads all died because they refused to stop and ask someone for directions to the food dish?\n",
        "date": "10/11/2018",
    },
    {
        "quote": "I accept that I am the odd minority in things like this and that my preference to not be acknowledged is not within the norms. It's why I wear the cowl and cape.\n",
        "date": "10/11/2018",
    },
    {
        "quote": "Velveeta + Rotel Tomatoes + a tiny bit of whole milk == Best cheese processed cheese food dip ever.\n",
        "date": "10/16/2018",
    },
    {
        "quote": "I guess ads don't really hurt me physically though (he said naively as he eye was drawn to something he had to purchase right now and he veered off the road...)\n",
        "date": "10/17/2018",
    },
    {
        "quote": 'Also in my vernacular, "overhyped" != "completely useless". Although I may use those as substitutes from time to time when ranting, for which I do apologize. You should always hear what I mean and not what I say, so that\'s on you \n',
        "date": "10/17/2018",
    },
    {
        "quote": "If they come with a bag of oatmeal cookies that slips over your face, they might finally lure me into an open plan seat.\n",
        "date": "10/18/2018",
    },
    {
        "quote": "The larger problem though (IMO) is that culturally/societal-ly we drive our most intelligent young people into unfulfilling and useless activities like this kind of wheel reinventing. This is a coding example, but the extreme example is finance, it exists only to serve itself and provides nothing of actual value(*) and yet $$$ attract some of the brightest mathematicians to spend careers working on the math behind the Next Big Financial Collapse. (* one could argue that finance has helped drive network latency down for all of us, but it's a tiny benefit relative to the intelligence drained by the industry)\n",
        "date": "10/25/2018",
    },
    {
        "quote": "I suppose everything is subjective from a certain perspective. I'd argue that spending that brainpower curing ingrown toenails is a better use of time than creating the next iteration of financial instruments to skim money off the economy though. Surely ingrown toenail math is at least somewhat interesting? Conway's Game of Life is mathematically interesting as are many, many things, but none of those have the associated monetary reward which Goldman Sachs can offer. I suspect interest in money markets comes after the salary negotiation in most cases.\n",
        "date": "10/25/2018",
    },
    {
        "quote": "That's scary. In the real world I might wind up in a tech support role having to deal with an academic asshole like ... ME!!!! \n",
        "date": "10/25/2018",
    },
    {
        "quote": "Such is the nature of walking chemical reaction vessels.\n",
        "date": "10/25/2018",
    },
    {
        "quote": "Whoever left half a donut in there, know that your willpower and self control make me sick. SICK!!!\n",
        "date": "10/19/2018",
    },
    {
        "quote": 'Thanks for joining us for another great episode of "Man writes script in Python and YOU WON\'T BELIEVE WHAT HAPPENS NEXT!"\n',
        "date": "10/31/2018",
    },
    {
        "quote": "6. Eat enormous breakfast. Rather than feeling primed and ready for an exciting day, begin fighting urge to take a nap at 7:30 AM.\n 5. Get egg carton out of fridge, realize there are three eggs left. “Can’t just take two and leave one, it’ll get lonely. Better have all three.”\n 4. Put Sweetened and Buttered oatmeal into microwave, return to start getting bacon out of pan and notice the bacon grease. “Bacon grease is great for making eggs, I’ll add a couple of fried eggs to this plate.”\n 3. Pour oatmeal into bowl and start to add water, but stop. “What this oatmeal needs is milk, butter and sugar.”\n 2. Stare at bacon frying and ponder eating it. “You know what would be good with that bacon, a bowl of healthy oatmeal.”\n 1. Get dog food out of fridge, notice some bacon nearing it’s expiry. “Better go ahead and eat that for breakfast so it doesn’t go to waste.”\n The downside (or upside, if you’re hungry) of working from home:\n",
        "date": "10/31/2018",
    },
    {
        "quote": "With any luck I'll be killed in a freak pizza accident before I retire and I won't have to deal with any of this. Such is my distaste for paperwork that I prefer a deep-dish based death over it.\n",
        "date": "11/2/2018",
    },
    {
        "quote": '"I\'m sorry Dave. I\'m afraid I can\'t do that."\n "Reboot, systemd."\n',
        "date": "11/2/2018",
    },
    {
        "quote": "I'm on target to a retirement filled with beans and rice and seasoned with roadkill.\n",
        "date": "11/2/2018",
    },
    {
        "quote": 'I misplaced my "outdoor" glasses and had to drive with my "indoor" glasses for a few days, it was no fun. With none at all, I probably shouldn\'t be walking around. But you may be onto something, it is a lot more relaxing to walk around among humanoid shaped blobs than actual people.\n',
        "date": "11/6/2018",
    },
    {
        "quote": 'I\'ll have to remember that. I do always take them off while eating, and I\'ve wondered sometimes if people think "why is that weird guy staring at me while eating" when in reality they are just a color spot in a modern art painting. I imagine someday a giant guy coming over and asking "why are you staring at my wife/girlfriend?" and I\'ll be like "what wife/girlfriend?" as I get punched in the face.\n',
        "date": "11/6/2018",
    },
    {
        "quote": '"The ninja crept quietly through the shadows, trailing behind his intended victim. Slowly he gained on his prey, making not even a whisper of sound. But it was wasted effort, because HIS TARGET WAS RUNNING A GOD DAMNED LEAF BLOWER AND NO ONE COULD HEAR ANYTHING!!!!"\n',
        "date": "11/7/2018",
    },
    {
        "quote": "Yesterday someone tried to charge ~5000 to my credit card at Zales in St. Louis, MO. I'm not sure what offends me more, that someone thought they could pretend to be me shopping at a jewelry store OR that someone thought they could pretend to be me in St. Louis, MO. Two places I would never intentionally go.\n",
        "date": "11/13/2018",
    },
    {
        "quote": '"Hi, welcome new EMC employees to your on-boarding training! The first week of this training will focus on effectively using your out-of-office vacation responder. Following this training there will be a one hour session covering how to enter your vacation days into our HR system, after which you\'ll be on vacation. Welcome aboard!!"\n',
        "date": "11/13/2018",
    },
    {
        "quote": "Good enough, I guess. If the whole retirement savings thing doesn’t work out then at some point I’ll just wander into the wilderness, casually flipping of the world as I fade into the underbrush.\n",
        "date": "11/14/2018",
    },
    {
        "quote": "The classic Tulsa joke is if I ever find out I only have a year to live, I'm moving to Tulsa because every day there is like an eternity.\n",
        "date": "11/16/2018",
    },
    {
        "quote": "Fake news! No way can they be successful and collaborate without having to wear noise canceling headphones to drown out the noise of an open plan office.\n",
        "date": "11/20/2018",
    },
    {
        "quote": "Ok, either fecal transplant is a good thing or a bad thing, I'm tired of this flip-flopping. But, pretty sure this is just  Big Iceberg Lettuce conspiracy to discredit romaine. Or maybe Butter lettuce. I've never trusted Butter lettuce, the name alone seems conspiratorial  and deceptive.\n",
        "date": "11/20/2018",
    },
    {
        "quote": "I've never been too impressed with very many of my doctors, maybe 10% of them have been really good and seemed genuinely interested in me as a person rather than another widget on the assembly line. I for one welcome our new AI based medical overlords, at least they won't bother wasting effort on trying to convince me they are human. A cold, objective determination that it's time for me to be euthanized will give me ironic satisfaction.\n",
        "date": "11/21/2018",
    },
    {
        "quote": "It's another step on the path forward and on a road unlikely to be a dead end in the long term.\n",
        "date": "11/21/2018",
    },
    {
        "quote": "Just for the record, mashed potatoes should be 100% yukon gold, no russets and they should be sliced/cubed and slowly simmered directly in the milk/butter rather than boiled in water with milk added later. This picture, while a nice metaphor for memory sharing, is an abomination for mashed potatoes.\n",
        "date": "11/27/2018",
    },
    {
        "quote": "The first rule of martian club is that you don't talk about martian club to people from other planets.\n",
        "date": "11/26/2018",
    },
    {
        "quote": 'I just got a recruiter email for the position "Medical Assistant". That\'s either a really poorly written LinkedIn candidate search or a golden invitation to hire me and have the place sued on my first day."Looks like you stuck your foot into the lawnmower, we\'ll just rub some bacon on that and it\'ll be fine. Now get out of here, cry-baby."\n',
        "date": "11/26/2018",
    },
    {
        "quote": "Something to ponder. I find myself falling into this trap where I will start doing something purely for myself and then the enjoyment will hit a pothole when I inevitably think about showing it to someone. Before our current online social culture I never bothered to show anyone anything, didn't care about external evaluations of my woodworking/rock climbing/etc activities at all. Yet, even with my walls of cynicism to protect me, the toxicity of social media's influence splashes over and lowers quality of life a notch or two. Always nice to be reminded that good enough for myself is often good enough and can be much more rewarding and enjoyable than eternally pursuing perfection, fame and/or fortune as determined by external measures and judgment. \n",
        "date": "11/27/2018",
    },
    {
        "quote": "I thought this would be a fun thing to do until noticing that I'm too old even to be useful for medical experiments.\n",
        "date": "11/27/2018",
    },
    {
        "quote": "'gone rogue' usually means you ignored the rules but aren't rich/powerful enough to get away with it.\n",
        "date": "11/28/2018",
    },
    {
        "quote": "Actual physics/technical limitations are meaningless once hype critical mass is achieved. I reject any science or logic based hurdles out of hand at this point. Quantum computing is inevitable, even if ultimately it is only simulated and becomes Yet Another Abstraction Layer.\n",
        "date": "11/28/2018",
    },
    {
        "quote": 'I like that since turning the workplace into a social club with a ballroom atmosphere, we now need "neurodiversity" to learn how to deal with people who are somehow broken because they just want everyone to shut up so they can work in peace.\n',
        "date": "11/28/2018",
    },
    {
        "quote": 'There\'s probably some room for interpretation around the idea of what "useful work" means. A person who digs a hole can look back at the end of the day and accurately measure "work", but "useful" requires a bigger picture view as digging that hole in a dam might be the exact opposite. I take the position that greater than half of all organizational effort is self-supporting waste/noise. In this case, simply allowing people more control over their work environment rather than categorizing them and building layers of effort and emotion on that categorization while trying to integrate them into an arbitrary "normal" environment could (I hypothesize) be better for everyone doing actual useful work. The utility of these categorizations and resulting fluff depends on accepting the status quo, which I pretty much reject as a sub-optimal solution. Biology won\'t overcome the downsides of taxonomy anytime soon and I suspect the human drive to categorize, sort and label individuals (with a heavy preference for a binomial metric) will haunt us until we are replaced by something better.\n',
        "date": "11/28/2018",
    },
    {
        "quote": "griznog hopes everyone has an anxiety attack and leaves him alone with 10 pizzas.\n",
        "date": "11/28/2018",
    },
    {
        "quote": "The only circulation in Polya is when the leaf blower blows it's exhaust into the offices.\n",
        "date": "11/28/2018",
    },
    {
        "quote": "I was thinking it's nice to hear the rain, then I remembered my house sits just above sea level beside a levee. Maybe I like droughts better.\n",
        "date": "11/29/2018",
    },
    {
        "quote": "If I had a dime for every time someone said \"I am not smart enough to figure out Makefile syntax, but surely I'm smart enough to write my own build tool!\" I'd have a lot of dimes.\n",
        "date": "11/30/2018",
    },
    {
        "quote": "I've punished you people enough with my presence today. Have a good weekend.\n",
        "date": "11/30/2018",
    },
    {
        "quote": "I feel your pain. Had BBQ last night, and decided to cure my meat coma/hangover with a morning round of diabetes.\n",
        "date": "11/30/2018",
    },
    {
        "quote": "Happy Donut. It's on El Camino in Mountain View, I think. Usually I can make myself drive past, but sometimes I get possessed and lose control of the truck.\n",
        "date": "11/30/2018",
    },
    {
        "quote": 'People believe in gods and ghosts and fairies and myriad other things passed to them consciously, many of which are far more destructive to themselves and those around them. I\'m willing to let Tesla call a feature that lets a sleeping/drunk driver stay in their lane "autopilot" without any reservations about it. For that matter, if they can monitor heart/health and automatically drive to the nearest hospital I\'d be ok with making it a mandatory technology for all cars. I see this article as being a huge win over the alternative of "sleeping driver causes fatal head-on collision."\n',
        "date": "12/3/2018",
    },
    {
        "quote": "The most disturbing part of that page is that somehow I have never stumbled across a cell phone mount for the steering wheel before, which I now realize I must have.\n",
        "date": "12/3/2018",
    },
    {
        "quote": "Last night I had a server (HP) fail to boot, it kept claiming a fan had failed and it would hit critical temp and stop. Ok, fine, it's 7+ years old it's served its purpose so I powered it off from the BMC and figured RIP. old fella. This morning it's powered on and running fine, been up for 7 hours. I'm tempted to change the hostname to \"lazarus.scg.stanford.edu\".\n",
        "date": "12/6/2018",
    },
    {
        "quote": 'The game begins.\n My reply, one line: "This is not a secure communication channel"\n Spammer, one line: "Did you get the mail i sent you regarding Mr Brian Hanks"\n',
        "date": "12/6/2018",
    },
    {
        "quote": 'I swear, every time I think "ok, maybe a container would work for problem X" and start digging into it, it\'s like making a call to a bottomless recursive function bad_ideas_and_poor_implementations() which returns a dictionary full of broken promises. How is this stuff so popular?\n',
        "date": "12/10/2018",
    },
    {
        "quote": '/me wanders off to find a web developer to punch in the throat.\n "Sorry, you can\'t use a P.O Box."\n Why yes, how did you know? Let me enter my mailing address. clickety clik clik\n "Unable to receive mail at this address?"\n Why yes, I do need to do that. clickety clik clik.\n "Update your address."\n',
        "date": "12/11/2018",
    },
    {
        "quote": "There is a double standard around Not Invented Here Syndrome, which combines with the reality that there are a lot more bad ideas than there are good ideas. As a result, an idea that is locally implemented successfully is called innovation, and an idea that locally fails is a case of NIH gone off the rails, despite having been the result of the same desire to produce something new and better. It becomes safer, especially for people prone to producing a higher ratio of bad ideas, to use canned, popular vendor solutions because as long as they are agreed to by a committee then no one can be blamed if they don't work well. Universities should be the one place where NIH syndrome is embraced, with as much being invented here as possible and failure owned and tolerated to extreme levels, even celebrated.\n",
        "date": "12/13/2018",
    },
    {
        "quote": 'sits on his hands using a new AI inspired feature of the latest release of griznog, called "Restraint in the face of ridiculous announcements."\n',
        "date": "12/13/2018",
    },
    {
        "quote": "I've always wanted a stalker, hopefully this lowers the bar enough so I can finally live the dream.\n",
        "date": "1/9/2019",
    },
    {
        "quote": '(If you are wondering to yourself "has griznog ever created several hundred IP aliases to annoy an IT department?", the answer is yes. Yes I have. )\n',
        "date": "1/15/2019",
    },
    {
        "quote": 'Maybe "annoy" is the wrong word. More like "guide to the correct action in an entertaining way."\n',
        "date": "1/15/2019",
    },
    {
        "quote": "I'd be surprised if as many as 50% of the people behind this lawsuit could pick a GPU out of a lineup if it was standing beside 4 hard drives. They speculated/invested in hype, it didn't work out and now they are sad but have no real understanding of what happened.\n",
        "date": "1/5/2019",
    },
    {
        "quote": 'The small car in front of me has the license plate "VIMRC". Somewhere out there is a vehicle that converts from car to truck to boat to plane, has a built in kitchen sink and pulls a trailer with the license plate "~/.emacs"\n',
        "date": "1/7/2019",
    },
    {
        "quote": "It's a little known fact that clowns invented compression with the RNE (Red Nose Encoding) algorithm first developed to put as many clowns as possible into a covered wagon, and later improved for modern tiny automobiles.\n",
        "date": "1/7/2019",
    },
    {
        "quote": "If only problems like this could be solved with a technical solution, that would be a wonderful world. A world where I would be unemplyed, but I'd be willing to take the hit.\n",
        "date": "1/8/2019",
    },
    {
        "quote": "This is what Schrodinger's box looks like if you put hype inside instead of a cat.\n",
        "date": "1/8/2019",
    },
    {
        "quote": "I have a deep admiration for ornery, I'm not sure how I feel about making someone less ornery.\n",
        "date": "1/8/2019",
    },
    {
        "quote": "At some point probably 35% of my body mass was made up of govt. cheese and bologna.\n",
        "date": "1/9/2019",
    },
    {
        "quote": 'I\'ve been thinking this whole wall thing through and I believe the focus on a "wall" has caused an huge opportunity to be missed. If we invade mexico, belize, guatemala, el salvador, honduras, nicaragua, costa rica and panama then we can have a MOAT!\n',
        "date": "1/11/2019",
    },
    {
        "quote": "I'm sorry @zyzhang but I have to assume your suggestion is a Chinese plot to distract us while you steal moat-related intellectual property.\n",
        "date": "1/11/2019",
    },
    {
        "quote": "YOU WON'T BELIEVE WHAT HE SAYS IN THIS SLACK POST! Looking at the headlines this morning, I had an epiphany about why I hate modern news and why social media is a completely broken entity. Everything that reaches us is pundit/moron fueled, over-dramatized gossip. Having grown up in a town with a population of < 200, I inherently loathe gossip and yet am drawn to it and thus it becomes self-loathing. I don't really care about the Bezos divorce, it has 0 impact on my life and hearing about it will drain away minutes of time I can't ever get back. And yet, my eye and mouse pointer feel a subtle pull toward the links... The only clear way out of this is life in an off-grid hermitage.\n",
        "date": "1/14/2019",
    },
    {
        "quote": "Assuming RH8 will be based on a 4 series kernel, the important question is will I live long enough to care about this?\n",
        "date": "1/17/2019",
    },
    {
        "quote": "My help system needs a help system which needs a help system...\n",
        "date": "1/25/2019",
    },
    {
        "quote": "Kronut holes to shove in your kronut hole. In the box are 24 - n holes, where n is a direct measurement of my shame and self-loathing.\n",
        "date": "1/25/2019",
    },
    {
        "quote": 'Although I\'ll note that he called me "John" Must not have my cowl pulled down all the way.\n',
        "date": "1/25/2019",
    },
    {"quote": "Exactly. Some people defy technical solutions.\n", "date": "1/24/2019"},
    {
        "quote": "I'll put it in the Batcave, in front of the waterfall.\n",
        "date": "1/30/2019",
    },
    {
        "quote": "On the contrary, you absolutely must click those, I use wget and throw away the result. Somewhere out there is a security theater employee whose sole purpose in life is to come up with stupid, worthless fake phishing attempts AND help bolster the number of troops in his security theater cohort to make his boss feel more important. Have a little human decency and fake a click on the link so this person can feel useful to society.\n",
        "date": "1/22/2019",
    },
    {
        "quote": 'What is it about people in general that makes some of them approach for help by saying "Can you help me with VOMIT FORTH VOLUMES OF DETAILS AND EXAMPLES and others approach for help by saying "I got an error, can you guess what it was and what I am trying to do and fix it for me?" I had never really considered it before but asking for help really is a skill that people have to learn one by one, just like any other.\n',
        "date": "1/24/2019",
    },
    {
        "quote": "It worked. I'm telling you, this is unlike anything I've ever seen. Clearly written by someone learning python, and yet, it worked.\n",
        "date": "1/30/2019",
    },
    {
        "quote": "boredpanda doest' like my adblocker, which is happening more and more often lately. To the point that what started out as a desire to simply avoid ads is gradually turning into a wonderful tool to keep me focused. Like right now instead of wasting time looking at that article I'm wasting time writing this in #random. That's progress!!\n",
        "date": "1/31/2019",
    },
    {
        "quote": 'Everyone should get a basic liberal arts education and introduction across all the sciences. In hindsight the smartest "mistake" I ever made was changing my major as an undergrad so many times it took almost 8 years to finish. I inadvertently wound up with a really, really broad base (and loans to match, but that\'s a different problem.) Too much focus makes it hard to see the bigger picture of things.\n',
        "date": "2/3/2019",
    },
    {
        "quote": "Introspection reveals that if I spent more time writing dot files for things, I'd probably remember enough of the syntax to be happy with it. Mostly I'm just whining that \"life is hard, waaaaaaaaahhhh, make it easier waaaaaaaaahhh\"\n",
        "date": "2/5/2019",
    },
    {
        "quote": "I stopped at that cupcake place in the Stanford Mall, I think they are 4 bucks each or some outrageous price. For the story we'll use 4 buck. Anyway, I had to know what a 4 dollar cupcake tasted like. To my surprise they have indeed mastered the art of the 4 dollar cupcake and should not accept a penny less than that for their efforts. A side effect is that I'm too cheap to buy a lot of cupcakes, so the economics work in my diets favor.\n",
        "date": "2/7/2019",
    },
    {
        "quote": "I've wanted to go to Kara's, but Town & Country Village exceeds my capacity for the amount of sheer human mass I can be around. Anything I do there is clouded by that.\n",
        "date": "2/7/2019",
    },
    {
        "quote": '"Let us be the iceberg to your titanic computing needs!"\n',
        "date": "2/11/2019",
    },
    {
        "quote": "Ah, Monday. So many open terminal windows, so little recollection what they were supposed to be doing....\n",
        "date": "2/11/2019",
    },
    {
        "quote": 'One of my biggest regrets in life is that I was well into adulthood before I knew the term "ginger" as it applies in a derogatory fashion toward people with red hair. I grew up with a cousin who had red hair and had I known this back then I could have spent my childhood calling him a "ginger freak" but sadly by the time I realized this was an option for taunting him, his hair was better described as grey or missing. Life lesson here: valuable opportunities can be lost if you aren\'t well versed in the ways of the world.\n',
        "date": "2/11/2019",
    },
    {
        "quote": 'For context here I was the smallest and youngest cousin and spent a fair amount of my time on the ground getting pummeled with the only available recourse to me being to give a good taunting. So things like this were very important in my formative years. I offer this to #random as a way of explaining where it comes from when I blurt out "oh yeah! Well your containers are full of cooties!" for no particular reason.\n ...\n your containers are full of cooties\n',
        "date": "2/11/2019",
    },
    {
        "quote": "You found a deeper meaning in my autobiographical #random than I had intended it to have, but this is food for thought. I often wonder if it was a simpler time back then and I got off easy. I mean on my end I only had to deal with sticks and stones, now I'm left to wonder if any of my words had lasting impact. Would I feel bad? I don't know, they are all Trump supporters now so probably not. Am I a !conservative because of the pummelings? Perhaps, perhaps. Many hammers come our way on the anvil of life.\n",
        "date": "2/11/2019",
    },
    {
        "quote": "Just heard a loud noise outside, first thought was a rhino was attacking us. Turns out the wind blew over my trash can (thankfully empty) and is pushing it down my carport.\n",
        "date": "2/13/2019",
    },
    {"quote": "They get Cookies in Chrome.\n", "date": "2/13/2019"},
    {
        "quote": "The social dynamics of all environments remind me of high school. It's not like 12th grade somehow advances us beyond being human.\n",
        "date": "2/14/2019",
    },
    {
        "quote": 'I really need to write a "help me help you" page.\n',
        "date": "2/14/2019",
    },
    {
        "quote": 'Because I am installing BOOST today I am waxing nostalgic. When you think of the pain of dealing with BOOST and think "how could that be any worse?", it could. As a naive and carefree young grad student I agreed to work on a project to implement the budding young proposed C++ STL as a tool for teaching introductory CS courses in C++. It was small enough at the time that I mostly got it done in about 3 or 4 months worth of grad-student effort (grad-student hours being a different unit of measure than person-hours because, not people). So could BOOST be worse? Imagine BOOST + sweatshop and really bad C++ coding and yes, yes it can.\n',
        "date": "2/15/2019",
    },
    {
        "quote": "Something needs to be done to stop the Boomers. Too bad our next election cycle can't have a rule that says no one over 45 can be elected to any office.\n",
        "date": "2/17/2019",
    },
    {
        "quote": "I wouldn't say I'm non academic, I personally favor free education for anyone willing to be educated. I am anti-academic-administration. I've either been a student or working in a university setting most of my life and I have watched academia  become smothered in people who simply have no real value. I'd like to see a free tuition program that paid university tuition for student if and only if the university maintained a faculty:student ratio of 1:30 and a faculty:administration ratio of 20:1.\n",
        "date": "2/18/2019",
    },
    {
        "quote": "There is no (as of today) incentive for academic administrations to reduce staff, IT or otherwise. The status quo reinforces itself by creating a hierarchy where there is a promise of power, fame and fortune if you can just amass a group under you by promising them the same thing... It's a classic pyramid scheme.\n",
        "date": "2/18/2019",
    },
    {
        "quote": "It becomes immediately clear how closely the problem solving attempts are tied to the technology they are familiar with, like us reverse engineering how the pyramids were built and having no context for applying mass human agony to the problem.\n",
        "date": "2/19/2019",
    },
    {
        "quote": "You know what's awesome about software written using BOOST? Nothing. Absolutely nothing is awesome about such software.\n",
        "date": "2/19/2019",
    },
    {
        "quote": "The leafblowers are blooming early this year, damn you climate change!!!\n",
        "date": "2/25/2019",
    },
    {
        "quote": "My simplified understanding of this is that prokaryotic life, on pretty much any planet with an ocean and hydrothermal vents with the right minerals nearby is pretty much mathematically inevitable. Eukaryotic life is more like WTF? How did THAT happen?\n",
        "date": "2/27/2019",
    },
    {
        "quote": "You know me as a jaded, cynical, pragmatic socialist, but back then I was an idealistic borderline militant socialist so I invested a lot of time in those rants and put them in the public domain.\n",
        "date": "2/28/2019",
    },
    {
        "quote": "Here's another data point for how far off the rails we are now. My wife just called me to ask what my phone number was because a) we've lost the ability to remember phone numbers and b) it's easier to just call than to try to navigate the contact and phone apps to find the number.\n",
        "date": "2/28/2019",
    },
    {
        "quote": "Had to install emacs and an emacs package (ess) today. Feel all dirty now, but it's a weird dirty feeling. Like if I knew the right key combination all the dirt would organize itself and find it's way to the correct dirt locations while simultaneously draining some portion of my life away.\n",
        "date": "3/6/2019",
    },
    {
        "quote": "Still kind of in shock over this, but a couple of days ago I ordered a 12v air compressor to put in my truck, just some random model from a long list of search results. I got the option of same day delivery and it was at my house about 6 hours later. Trying to wrap my head around that. I grew up with a \"party\" landline phone, 1 TV station and monthly or at most bi-monthly trips to the big-city grocery store. Now I can buy something on my phone, which works everywhere and they'll bring it to me in 6 hours. It doesn't seem like I've been alive long enough for a shift of that magnitude.\n",
        "date": "3/7/2019",
    },
    {
        "quote": "I can see that cheating on SATs is wrong, that's cheating, but I've always assumed donations-for-admission was just part of the normal private university business model.\n",
        "date": "3/12/2019",
    },
    {
        "quote": "Evolution does not reward good design or intelligence, it rewards successful reproductive strategies.\n",
        "date": "3/14/2019",
    },
    {
        "quote": "Next is spaghetti-o's oriented architecture, crappy code nobody likes but in easy to stack containers.\n",
        "date": "3/14/2019",
    },
    {
        "quote": "I love the smell of pretentiousness in the morning.\n",
        "date": "3/14/2019",
    },
    {
        "quote": "Heavy traffic today, barely made it home in time to catch the last of the neighbors leaf blowing.\n",
        "date": "3/14/2019",
    },
    {
        "quote": "It's sunny and 60+, anybody up for walking to a ${LUNCH_DESTINATION} that is at least a mile away or across campus?\n",
        "date": "3/15/2019",
    },
    {
        "quote": "Anytime. Thrid breakfast is in the history books now and it's time to move on.\n",
        "date": "3/15/2019",
    },
    {
        "quote": "Of course, money makes water flow uphill,, so there's that.\n",
        "date": "3/19/2019",
    },
    {
        "quote": "I'd offer my opinion, but the fact that there is a market for this that is supporting companies speaks louder.\n",
        "date": "3/19/2019",
    },
    {
        "quote": "It seems to me that getting 'unbiased data' is about as likely as finding an 'unbiased data scientist' to work with it, which is to say p is very near zero for it happening. We are entering a world where 'lies, damned lies and statistics' will need to be updated to 'lies, damned lies, statistics and big data.'  Anything in which humans are allowed to stir the pot in any way will always have some sort of bias in it and that bias will most likely reflect the stirrers of the pots own best self-interest.\n",
        "date": "3/20/2019",
    },
    {
        "quote": "summer vacation could go away as well. If all these stupid kids aren't going to be working on the farm, they can sit in a classroom somewhere so I don't have to look at them.\n",
        "date": "3/26/2019",
    },
    {
        "quote": "We'll send a technician between Monday and Friday, sometime between 8 AM and 5 PM, will you be home?\n",
        "date": "3/27/2019",
    },
    {
        "quote": "I'm not making fun of the research computing effort, what I'm (satirically) pointing out is what happens when an IT mentality gets involved and positions get squandered on people and activities which provide little relative value to the research support mission, Clearly there is nuance there in any environment, but when directors outnumber sysadmins something has gone off the rails.\n",
        "date": "4/9/2019",
    },
    {
        "quote": 'At the time that stuff was so painful to make work and the benefits were so few because there was nothing really to do on the network except maybe play Doom. I was about to wax nostalgic and say "well, we suffered a lot back then with crude technology but it was all worth it, look at the internet now" but then I looked at the internet and now I\'m wondering was it really worth it?\n',
        "date": "4/12/2019",
    },
    {
        "quote": "Somebody's bird, parakeet, or some kind of songbird, set up a concert outside my bedroom window last night. I was awake listening to bird song at 3 am. Need to get myself a pellet gun with a night vision scope.\n",
        "date": "4/23/2019",
    },
    {
        "quote": "You'd also think that given the amount of cat crap I have to clean up out of my yard I would not have a problem like this. Two reasons to get that pellet gun.\n",
        "date": "4/23/2019",
    },
    {"quote": "I'm a redneck, I never read the instructions.\n", "date": "4/26/2019"},
    {
        "quote": "What is discouraging about it, and all the slack clones, is that none of them seem to think that just doing what slack does, but better and more elegantly and with little things fixed, like fully functional threads, working/useful search, more control over notifications, etc., and instead seem to think they need to add some new layer(s) of flashy features to disrupt the paradigm or whatever the kids are calling it these days. Facebook certainly has the resources to build a better slack and instead they built another intrusive facebook monstrosity.\n",
        "date": "4/29/2019",
    },
    {
        "quote": "Nobody wants to make things Just Work(tm) anymore, if it's not flashy and shiny and disruptive then there's no interest. But somebody has to keep the sewers flowing, even if it's not sexy. And with that I've completed my hijacking of this thread and turning it into an old man rant.\n",
        "date": "4/29/2019",
    },
    {
        "quote": "That is heartbreaking. I feel like there should be some Sarah Mclachlan music playing with a voiceover asking for donations to save abused and unwanted calculators.\n",
        "date": "5/2/2019",
    },
    {
        "quote": "This is truly random, but if you wanted an indicator for how bad the opioid crisis is, the truck stop we visited in Nevada had a biohazard sharps disposal container, which was full.\n",
        "date": "5/4/2019",
    },
    {
        "quote": "The whole them vs us thing is pretty silly for a bunch of walking meat bags filled with bacteria who all share the same space rock, but ... humans. What ya gonna do?\n",
        "date": "5/13/2019",
    },
    {
        "quote": "I love it when I don't like something but am not smart enough to figure out why I don't like it and then someone who is smart enough writes it all out in an article so that even I can understand why it sucks. Great blog post.\n",
        "date": "5/19/2019",
    },
    {
        "quote": '"Your science is the best. Your lab only hires the best postdocs. Your students are all Rhodes scholars. You are kind of a big deal. You deserve Sherlock Platinum, because ... you\'re worth it."\n',
        "date": "5/22/2019",
    },
    {
        "quote": ' Me: "No, you have the wrong number."\n Them: "Is Nathan there?"\n Me: "Hello"\nThem: "Well it could be the right number if you give me a moment to tell you about our vacation packages..."\n/me searches for the "carpet bomb other end of connection" button but can\'t find it in Android.\n',
        "date": "6/5/2019",
    },
    {
        "quote": "The whole phenomenon maps nicely onto a cluster management analogy, actually. There are still people trying to make a business around managing an HPC cluster, Bright, for example. The key thing in these types of technology areas is marketing. The goal is to basically convince an eskimo not just that they need to buy your freezer, but to also pay extra for the ice it produces on a per-cube basis. So the technology is a distant second in importance to the company’s marking and sales team. (Question: Has political correctness and climate change rendered the eskimo/freezer metaphor offensive and/or useless at this point?)\n",
        "date": "6/17/2019",
    },
    {
        "quote": 'Can you get your title officially changed to Don? Don Guido, head of the Research Computing family. "Those are some nice jobs you have there, it\'d be a shame if anything were to happen to them."\n',
        "date": "6/19/2019",
    },
    {
        "quote": 'Also if you read all that backwards it says "paul is dead". Both "griznog" and "satanic" have 7 letters ... coincidence?\n',
        "date": "6/19/2019",
    },
    {"quote": "If it's not monetized, it didn't happen.\n", "date": "7/13/2019"},
    {
        "quote": 'Oh crap, that is 110% my fault. I have a chrome plugin that replaces "cloud" with "my butt" but it\'s not supposed to modify inside text boxes. I\'m absolutely positive that snuck in when I edited the SCG section.\n',
        "date": "7/17/2019",
    },
    {
        "quote": "As you get older your first crows feet and other wrinkles will be shocking like this. Over time there are two directions to take, 1), embrace the process and celebrate it as the natural progression of life or 2) coat yourself with potions and embark on a journey of scalpels to fight the inevitable. My collected observations so far are that people in category 1 seem to be generally happier and more content. I'd say those marks give the laptop character and are a visible record of its history and life with you and be happy for the memories (at least until the DIMMs/SSD wear out and they are gone forever).\n",
        "date": "7/12/2019",
    },
    {"quote": "So lonely out there, must be wonderful.\n", "date": "7/17/2019"},
    {
        "quote": "And piping scripts from a website and letting them run sudo seems like it couldn't possibly go wrong.\n",
        "date": "7/19/2019",
    },
    {
        "quote": "Having spent my first working decade doing things like digging ditches or harvesting timber or making plywood, it was a real shock to me and still is actually that a lot of people never do actual sweat inducing work, they just exercise social skills in some arbitrary hierarchical setting with a positive feedback/ confirmation-bias loop. This is one reason I love racking servers, it's the one part of my job where I actually feel like I'm earning my paycheck.\n",
        "date": "7/21/2019",
    },
    {
        "quote": "We'll be riding ContainerLESS unicorns over setuid root rainbows!!!\n",
        "date": "7/31/2019",
    },
    {
        "quote": '"Hi V.C. Moneybags, here\'s my elevator pitch for SomethingElse(tm), I think you\'ll love it. First we start by coming up with new names for all the things SomethingElse(tm) will do so the naive customers don\'t realize that OtherThing(tm) already does what they need. Next, we hire a crack PR and Marketing team to "leak" exciting info about SomethingElse(tm) describing all the stuff it will do. Last, we outsource coding SomethingElse(tm) to low-paid subcontractors via a shell corporation in the US so we can claim SomethingElse(tm) is American Made. We release version 1.0 of SomethingElse(tm) the day after our IPO, shortly after we all cash in our stock options."\n',
        "date": "8/1/2019",
    },
    {
        "quote": "Well, to be fair, I don't expect scammers to really be all that professional. And to be fairer, I can be pretty frustrating to deal with (at least according to my wife and kids, who fall into the same category as scammers for many of my conversations with them.)\n",
        "date": "8/12/2019",
    },
    {
        "quote": "When I was a kid I worked with a guy who bought an AR15 and several 25 round clips, which he taped together so he could swap them quickly, all for the single purpose of killing feral hogs. He got all his shiny new gun together one night and drove quietly out to a spot in his pasture he had been baiting for weeks. Opened the door, got out and slipped the safety off then had someone I the truck turn the lights on. Out in front of the truck was a big herd of hogs, from big to baby and he opened fire. Pigs were squealing and running around, dirt was flying, brass ejecting as fast as he could shoot until he ran through both clips. Walked out into the field to find ... not a single drop of blood anywhere. Moral of the story is that some people may need assault rifles, but not the ones who are dumbasses.\n",
        "date": "8/6/2019",
    },
    {
        "quote": "Resistance is futile, but never buying Dell again is easily within my grasp.\n",
        "date": "8/12/2019",
    },
    {
        "quote": 'I\'m trying to go the other direction, where in about 10 years everyone forgets my name and I become "that useless weird guy who rides around on his tractor and goes fishing a lot."\n',
        "date": "8/12/2019",
    },
    {
        "quote": "One person's highway robbery is another person's completely valid wealth redistribution. Perspective matters and really, do people who can't make a simple web page deserve to keep their $18k?\n",
        "date": "8/14/2019",
    },
    {
        "quote": "My biggest complaint about Jupyter notebooks is that they trick people into believing they know how to use a computer.\n",
        "date": "9/30/2019",
    },
    {
        "quote": "If someone is sick, it's only because they haven't been punished enough to decide to stop being sick. This is the American way. Also s/sick/poor/g works there.\n",
        "date": "9/27/2019",
    },
    {
        "quote": "Singularity: the MySpace of container management...\n",
        "date": "9/23/2019",
    },
    {"quote": "All operating systems want to be linux.\n", "date": "9/23/2019"},
    {
        "quote": "Anyone with grandparents knows that ingrained cultural norms/attitudes do not change easily within a person. Plus modern society and mores are evolving at a rate that is faster than generational turnover, so some people will adapt to that and others will be shamed/marginalized/early_retired. And there will always be pockets where there is little or no evolution (I'm looking at you, Mississippi.) You do what you can, pressure and time are required.\n",
        "date": "9/25/2019",
    },
    {
        "quote": "oh, yeah. That's my commute. I'm the only one who knows I'm racing.\n",
        "date": "9/20/2019",
    },
    {
        "quote": "I think more and more things like github, notebooks, containers, etc., are becoming the geek/nerd/techno/${YOUR_FAVORITE_CLASSIFICATION_HERE} equivalent of comments on youtube videos. No one really reads them except people whose life revolves around youtube video comments and they really become little micro-community echo chambers occasionally ravaged by a passing troll*.Disclaimer: This comment may or may not have been made by a passing troll in a micro-community echo chamber. What do you think? Answer in the comments below!\n",
        "date": "9/3/2019",
    },
    {
        "quote": 'It\'s not that I think that all github repos are bad or all containers are bad or even all notebooks are bad, just like some non-zero amount of good things happen on facebook and I personally learn a ton of stuff from youtube (but avoid ever reading the comments). I do think, however, that all these platforms generate a LOT of noise which is, for lack of a better description, really just noise. And much like my singing in the shower, I\'m not convinced it all needs to be published. It\'s especially annoying because far too many people still operate under the "I saw it on the Internet, it must be true" paradigm and a whole generation of "content" producers have confused "ease of publishing" with "worth publishing".\n',
        "date": "9/3/2019",
    },
    {
        "quote": "Oh, certainly, I take anything in your python notebooks as if it were the word of god passed down to us on stone tablets. Simply because of your meticulous curation of them. How could they possibly contain anything that wasn't nobel quality science?\n",
        "date": "10/30/2019",
    },
    {
        "quote": "It also always fascinates me that a company that wants to sell me storage and networking gear would place a limit on uploads.\n",
        "date": "10/23/2019",
    },
    {
        "quote": 'I hope everyone who ever worked or works on a "display pdf in the browser" project gets bedbugs.\n',
        "date": "10/22/2019",
    },
    {
        "quote": "No, but it's worth grabbing to use when you want a getaway car. A Utah plate really throws off suspicion.\n",
        "date": "10/16/2019",
    },
    {
        "quote": "Most earthquakes are preceded by a sunrise no more than 24 hours prior to the earthquake. Coincidence? I think not. The key is determining which sunrises precede earthquakes.\n",
        "date": "10/15/2019",
    },
    {
        "quote": 'I just got a text from Carla, she\'s coming back from visiting kids and the text read "Never again Frontier". I could retire if somehow I could get paid a nickel every time someone sends that message.\n',
        "date": "10/7/2019",
    },
    {
        "quote": "As you get older, where you work affects how much you look forward to using the bathroom less and less. It begins to stand on it's own merit as an activity to celebrate.\n",
        "date": "10/3/2019",
    },
    {"quote": "I have to listen to these voices all the time.\n", "date": "10/3/2019"},
    {
        "quote": "I'll need better drool technology if this goes on much longer.\n",
        "date": "11/13/2019",
    },
    {
        "quote": 'You know you are in trouble when they send 1 of everything and tell the tech to basically  "replace parts in this order until it starts working or you run out of parts"\n',
        "date": "11/8/2019",
    },
    {
        "quote": "Windows must be having a hard time picking out an outfit, this is taking a while. I'm worried we'll be late for the Malware party. Or will we be ... fashionably late?\n",
        "date": "11/1/2019",
    },
    {
        "quote": 'Nobody in the tech industry understands the concept of "just because you can doesn\'t mean you should."\n',
        "date": "11/28/2019",
    },
    {
        "quote": "And if you are thinking I left out the vegetables, wrong. There is ketchup. Lots of ketchup.\n",
        "date": "11/26/2019",
    },
    {
        "quote": "Many ssh sessions have been killed. The tree of network liberty must be watered with the blood of innocents from time to time.\n",
        "date": "11/26/2019",
    },
    {
        "quote": "Thanks all. The Shrimp is a reference to my family having abandoning holiday turkey and ham when I was a kid and switching to seafood, we usually make an enormous platter of fried shrimp, french fries and hushpuppies. The only way to improve it would be to move Thanksgiving to crawfish season, but I don't have the authority to do that yet.\n",
        "date": "11/26/2019",
    },
    {
        "quote": 'My dentist doesn\'t offer gas, which is #sad. I asked a previous dentist if gas really helped and his response was "it makes you feel better about going to the dentist" which I see as a completely legitimate reason to get the gas.\n',
        "date": "12/2/2019",
    },
    {
        "quote": "That is a fascinating traffic flow phenomenon which I observed on the Red line in Boston frequently. The delays caused by everyone on the platform trying to crowd into the first train inevitably produced a near empty train following it.\n",
        "date": "12/2/2019",
    },
    {
        "quote": "That's like finding a clown in your closet in your clown-proof house you paid extra for.\n",
        "date": "12/5/2019",
    },
    {
        "quote": "It's true. I'm going to the dark side. I'm even buying some long pants and shirts with collars.\n",
        "date": "12/9/2019",
    },
    {
        "quote": "I have a stuffed teddy bear in a Robin costume, but the photographer made Carla move it for the pictures. And the BatTruck is right there in the driveway, but hidden behind the stairs so no one suspects I live here.\n",
        "date": "12/11/2019",
    },
    {
        "quote": "You I'll miss. But the house gets replaced with an open bit of pasture surrounded by trees, so house not so much. I think I'd like to have wild pigs for neighbors for a while, if they make too much noise then we can settle it amongst ourselves and I can have sausage for breakfast.\n",
        "date": "12/11/2019",
    },
    {
        "quote": "Will be WFH tomorrow, have an appointment near home mid-day. Also a non-zero probability I'll just stand on the street corner and yell at passing cars. Is this year over yet?\n",
        "date": "12/12/2019",
    },
    {
        "quote": 'I drive home past a Google building with "I LOVE APIS" in the window in giant letters made by sheets of paper. I always want to stop and set fire to those letters.\n',
        "date": "12/13/2019",
    },
    {
        "quote": "I can't believe Intel would ever have a roadmap slip, next you'll be making the outrageous claim that the sun will rise tomorrow morning.\n",
        "date": "12/15/2019",
    },
    {
        "quote": "Best impeachment ever. I hear, people are saying, there's never been a better impeachment.\n",
        "date": "12/18/2019",
    },
    {
        "quote": "If one needed evidence of the impending fall of civilization, one need look no further than to create a request for said evidence and then try to print it. The idea we'll fix anything in the long term with technology is an utter joke.\n",
        "date": "12/12/2019",
    },
    {
        "quote": "I was ranting more along the lines that printing itself should either be seamless or unnecessary by now, not an ongoing clusterfsck to use and consumer of resources. However, as a big fan of unplugged woodworking using 100% human power, I'm not opposed to switching to stone and chisels. It has a way of distilling a project down to its base needed elements and discarding the cruft.A tiger team to meet twice a week and plan digging a ditch might be large, but the tiger team to dig it by hand with picks and shovels will not get many volunteers.\n",
        "date": "12/13/2019",
    },
    {
        "quote": 'Years ago when I was younger and dumber and had no (fewer?) filters, I met with a bee biologist with an impressive title and lots of influence who opened the meeting by beginning to tell me how I was going to run his systems for him, in gory (and misguided) technical detail. I interrupted him and said, basically, "I\'m not going to tell you how to do bee research and you aren\'t going to tell me how to run computing resources." After that we got along fine.I think you get back out of every relationship what you bring to it and while I accept that I exist to serve and help others I do so voluntarily because that is what I perceive myself as being good at and because the best way to help in our space is by applying critical thinking skills, experience and expertise to the problems. If someone already knows "how it should be done" and are just looking to give orders to a servant, then they don\'t need me because the world is full of IT Orgs that are willing to do/suffer anything to justify more FTE drones on the org chart.\n',
        "date": "12/13/2019",
    },
    {
        "quote": "West Texas is the opposite of claustrophobic.  This is where they grow tshirts.\n",
        "date": "12/22/2019",
    },
    {
        "quote": "Did anyone in the engagement survey report feeling over-engaged?\n",
        "date": "07/2019",
    },
    {
        "quote": "Qualys is trying to frame me for crimes I didn't commit. Which is senseless, there are so many crimes that I did commit…\n",
        "date": "03/2018",
    },
    {
        "quote": "Remote security professionals. Interesting. I bet that makes a CIO-like person tingle with a sense of pride and accomplishment. …  We could be ISO employees on a quiet beach somewhere occasionally forwarding a pdf of best practices and checking a box.\n",
        "date": "01/2018",
    },
    {
        "quote": "I like that, it exploits my natural talent for breaking things.  I'm too lazy to go to Whitman levels, Kevorkian is more my style. Relaxed, quiet, no crowd and consent.\n",
        "date": "01/2018",
    },
    {
        "quote": "I can support chemists if needed. They are like biologists except they think their crappy software is worth money.\n",
        "date": "12/2017",
    },
    {"quote": "Always happy to deny responsibility.\n", "date": "11/2017"},
    {
        "quote": 'Heading over to meet with a user in the "Infectious Disease Department", if the zombie apocalypse breaks out you can tell everyone you knew patient zero.\n',
        "date": "09/2017",
    },
    {
        "quote": "Knowledge? Map of skeletons in closets? I've not been able to turn mine into a successful blackmail campaign to fund my retirement, maybe you will have better luck.\n",
        "date": "09/2017",
    },
    {
        "quote": "Climate change is huge. Enormous. Ironic that simulating it may be the thing that is causing it.\n",
        "date": "09/2019",
    },
    {
        "quote": "John has children and grandchildren, but no great-grandchildren. Some of the grandchildren are pretty good, but none have yet reached “great” status. John's one special skill and talent is a complete immunity to peer pressure, however, he's willing to change that if enough people want him to.\n",
        "date": "09/2017",
    },
    {
        "quote": "I don't know the current contents, but when I was in high school in Texas, there was never any mention of Darwin or evolution and 8 years later when I was teaching math in a texas high school and asked the biology teacher about it, she said she was expressly forbidden from mentioning it. It's important to remember that stupidity in positions of authority tends to preserve stupidity. \"Willful ignorance \" may be a more politically correct word instead of stupidity, but really stupid is much more descriptive in my stupid opinion. Texas is located on an arguably flat, divinely white and perky young 6000 year old earth. What it lacks in reality, it makes up for with endless opportunities for me to offend people who attempt to engage me in small talk.\n",
        "date": "1/15/2020",
    },
    {
        "quote": "I firmly believe people are generally good. Until you give them anonymity in a group, at which point they are capable of doing very bad things. That group can be a company, army, country, church, $LOCAL_RACIST_ORG, etc. It feels like evil has the potential to easily scale exponentially with group size, while good ... not so much. The exception perhaps being disaster relief, although even in that case it tends to be a meta group of many smaller groups in the end and they only come out for special occasions, where evil groups seem to never sleep.\n",
        "date": " 1/15/2020",
    },
    {
        "quote": "We should monetize our own butt-scan stream before the hackers do it.\n",
        "date": "1/14/2020",
    },
    {
        "quote": "I showered this morning, so I don't think the nauseating smell was me. Although I also had a lot of cabbage last night, so maybe I'm not entirely innocent....\n",
        "date": "1/8/2020",
    },
    {
        "quote": "Setting up a container to run a Java app is a clear indication that humanity is doomed to self-destruct.\n",
        "date": "1/10/2020",
    },
    {
        "quote": "Sounds like a method of diverting public funds for science to cloud providers, I have no doubt it'll be popular.\n",
        "date": " 1/15/2020",
    },
    {
        "quote": "I've never really found winsecure all that restricting. winsecure is basically like storing all your nitroglycerin on top of your washing machine, then washing your sneakers to see what happens.\n",
        "date": " 1/9/2020",
    },
    {
        "quote": "This is true. Also I would have replied sooner but was picking my butt.\n",
        "date": " 1/15/2020",
    },
    {
        "quote": "I'm more fascinated by a bad idea encapsulating a bad idea being a great example of how we'll destroy ourselves in the end.\n",
        "date": "1/10/2020",
    },
    {
        "quote": "I didn’t label anything>? I hope thats not a problem.\n",
        "date": "2019",
    },
    {
        "quote": "Texas people are my kinda people, you wouldn’t understand.\n",
        "date": "2019",
    },
]



#!/usr/bin/env python

"""

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""

import griznog
import argparse
from glob import glob
import sys
import os
import re
import tempfile


def get_parser():
    parser = argparse.ArgumentParser(description="Griznog, captured in code")
    parser.add_argument(
        "--version",
        dest="version",
        help="print the version and exit.",
        default=False,
        action="store_true",
    )

    subparsers = parser.add_subparsers(
        help="griznog actions",
        title="actions",
        description="actions for Griznog",
        dest="command",
    )

    speak = subparsers.add_parser("speak", help="ask Griznog to speak his wisdom.")

    speak.add_argument(
        "--topic",
        dest="topic",
        help="subset to particular topic.",
        type=str,
        default=None,
    )

    speak.add_argument(
        "--pause",
        dest="pause",
        help="seconds to allow Griznog to breathe between spurts (default 3 seconds).",
        type=int,
        default=3,
    )

    speak.add_argument(
        "--dump",
        dest="dump",
        help="Just hear everything. Optionally set a --pause (seconds)",
        default=False,
        action="store_true",
    )

    speak.add_argument(
        "--no-color",
        dest="nocolor",
        help="disable color",
        default=False,
        action="store_true",
    )

    return parser


def main():
    """main is the entrypoint to griznog. Get your head out of the gutter.
    """

    parser = get_parser()

    # Will exit with subcommand help if doesn't parse
    args, extra = parser.parse_known_args()

    # Show the version and exit
    if args.version:
        print(griznog.__version__)
        sys.exit(0)

    # Initialize the JuliaSet
    if args.command == "speak":

        from griznog import Griznog

        human = Griznog()

        # Case 1: dump all the wisdom, optionally limited to a topic/date
        if args.dump:
            human.dump(topic=args.topic, pause=args.pause, add_color=not args.nocolor)

        # Case 2: Randomly speak, optionally filter to topic/date
        else:
            human.speak(topic=args.topic, add_color=not args.nocolor)

    else:
        parser.print_help()


if __name__ == "__main__":
    main()



"""

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

Modified from https://github.com/Visual-mov/Colorful-Julia (MIT License)

"""

from datetime import datetime
import os
import re
import random
import sys

here = os.path.dirname(os.path.abspath(__file__))


def colorize(text):
    """add color to the prompt
    """
    off = "\033[0m"  # end sequence
    colors = {
        "CYAN": "\033[36m",
        "PURPLE": "\033[95m",
        "RED": "\033[91m",
        "DARKRED": "\033[31m",
        "YELLOW": "\033[93m",
    }
    color = random.choice(list(colors.keys()))
    return "%s%s%s" % (colors[color], text, off)



"""

Copyright (C) 2019-2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""

from .version import __version__
from .body import Griznog



"""

Copyright (C) 2019-2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""

from griznog.wisdom import thoughts
from griznog.utils import colorize
import random
import re
import sys
import time


class Griznog(object):
    """A Griznog is a packet of human meat (primarily carbon based, multi-cellular)
       that comes with infinite wisdom and a huge desire for pizza and the occasional
       donut. Allergies include too many other humans, useless organizational
       powers, and leaf blowers.
    """

    def __init__(self):
        self.quotes = thoughts

    def __str__(self):
        return "[griznog]"

    def __repr__(self):
        return self.__str__()

    def _speak(self, thought, add_color=True):
        """Speak a random thought, or one selected from a subset.
        """
        quote = thought["quote"]
        if add_color:
            quote = colorize(quote)
        print("%s\n--Griznog %s" % (quote, thought["date"]))

    def dump(self, topic=None, pause=3, add_color=True):
        """dump all knowledge, optionally filtered to a topic.
        """
        thoughts = self.quotes
        if topic is not None:
            thoughts = self.filter_thoughts(thoughts, topic)

        # Always randomize
        random.shuffle(thoughts)

        for thought in thoughts:
            self._speak(thought=thought, add_color=add_color)
            print("\n\n")
            time.sleep(pause)

    def filter_thoughts(self, thoughts, query):
        """filter a set of thoughts down based on a query string. We make
           the query and the quotes lowercase to support any casing
        """
        thoughts = [t for t in thoughts if re.search(query.lower(), t["quote"].lower())]

        if not thoughts:
            print("Griznog doesn't have anything to say about %s." % query)
            sys.exit(0)
        return thoughts

    def speak(self, topic=None, add_color=True):
        """Ask Griznog to speak his wisdom
        """
        thoughts = self.quotes
        if topic is not None:
            thoughts = self.filter_thoughts(thoughts, topic)

        thought = random.choice(thoughts)
        self._speak(thought=thought, add_color=add_color)



"""

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

"""

__version__ = "0.0.1"
AUTHOR = "Vanessa Sochat"
AUTHOR_EMAIL = "vsochat@stanford.edu"
NAME = "griznog"
PACKAGE_URL = "http://www.github.com/vsoch/griznog"
KEYWORDS = "griznog, wisdom"
DESCRIPTION = "Your own personal Griznog, wisdom on demand"
LICENSE = "LICENSE"

################################################################################
# Requirements

INSTALL_REQUIRES = ()

TESTS_REQUIRES = (("pytest", {"min_version": "4.6.2"}),)

INSTALL_REQUIRES_ALL = INSTALL_REQUIRES
